import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import theme from './../components/theme'

const getTextStyle = ({ fontSize, fontWeight, lineHeight, letterSpacing }, textStyle) => ({
  fontSize,
  fontWeight,
  lineHeight,
  letterSpacing,
  ...(textStyle.indexOf('caps') > -1 ? { textTransform: 'uppercase' } : {}),
  ...(textStyle.indexOf('mono') > -1 ? { fontFamily: theme.fonts.mono } : {})
})

const getClassName = ({
  textStyle,
  bold
}) => css({
  ...getTextStyle(theme.textStyles[textStyle], textStyle),
  ...(bold ? { fontWeight: '500' } : {})
})

const parseProps = ({
  textStyle,
  bold,
  className,
  ...props
}) => {
  if (textStyle !== undefined || bold !== undefined) {
    return {
      className: cx(className, `${getClassName({ textStyle, bold })}`),
      ...props
    }
  }
  return { className, ...props }
}

const withTextStyles = (Comp) => {
  const TextStylesComp = props => React.createElement(Comp, parseProps(props))

  TextStylesComp.propTypes = {
    ...Comp.propTypes,
    textStyle: PropTypes.oneOf(Object.keys(theme.textStyles)),
    bold: PropTypes.bool
  }

  TextStylesComp.displayName = Comp.displayName

  return TextStylesComp
}

export {
  withTextStyles
}
