import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Box,
  Pane,
  Content,
  Link,
  theme
} from '../components'

export default function boxStory (module) {
  storiesOf('Box', module)
    .add('usage', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Box

The Box component is the base component for most other components, by default it is a \`div\`.
All the higher order components in \`enhancers\` are applied to Box.

## is='...' API

\`\`\`
<Box>div by default</Box>
<Box is='span'>now a span</Box>
<Box is='h1'>now a h1</Box>
<Box is='a'>now a anchor tag</Box>
<Box is={Link}>now a Link, use with caution</Box>
\`\`\`

## Display API

Available on \`<Box />\` or \`withDisplay(Comp)\`.
Uses inline styles.

\`\`\`
<Box display='block' />
<Box display='inline-block' />
<Box display='flex' />
\`\`\`

prop | value | description
-----|-------|-------------
\`display\`| block, inline-block, inline, table, table-row, table-cell, flex, inline-flex | display: x;

## Dimensions API

Available on \`<Box />\` or \`withDimensions(Comp)\`.
Uses inline styles.

\`\`\`
<Box width='200px' />
<Box width={6} />
<Box height='40px' />
<Box height='40px' width='40px' />
<Box minWidth='100px' />
\`\`\`

prop | type | description
-----|------| -------
\`height\`| string | height: x;
\`width\`| string/[1..12] | given a number 1..12 as x, return {100/x}%
\`minWidth\`| string | min-width: x;
\`minHeight\`| string | min-height: x;
\`maxWidth\`| string | max-width: x;
\`maxHeight\`| string | max-height: x;

## Text Styles API

Available on \`<Box />\` or \`withTextStyles(Comp)\`. Uses glamor.

\`\`\`
<Box textStyle='display1'>Display (1)</Box>
<Box textStyle='display2'>Display 2</Box>
<Box textStyle='display3'>Display 3</Box>
<Box textStyle='display4'>Display 4</Box>
<Box textStyle='display5'>Display 5</Box>
<Box textStyle='body1'>Body (1)</Box>
<Box textStyle='body2'>Body 2</Box>
<Box textStyle='mono'>Mono</Box>
<Box textStyle='caps1'>Caps 1</Box>
<Box textStyle='caps2'>Caps 2</Box>
\`\`\`

`}
          </Content>
          <Box textStyle='display1'>Display (1)</Box>
          <Box textStyle='display2'>Display 2</Box>
          <Box textStyle='display3'>Display 3</Box>
          <Box textStyle='display4'>Display 4</Box>
          <Box textStyle='display5'>Display 5</Box>
          <Box textStyle='body1'>Body (1)</Box>
          <Box textStyle='body2'>Body 2</Box>
          <Box textStyle='mono'>Mono</Box>
          <Box textStyle='caps1'>Caps 1</Box>
          <Box textStyle='caps2'>Caps 2</Box>
          <Content markdown>
{`

prop | type | description
-----|------|------------
\`textStyle\` | display1, display2, display3, display4, body1, body2, mono, caps1, caps2 | use text style

## Spacing API

Available on \`<Box />\` or \`withSpacing(Comp)\`.
Uses inline styles. Uses the spacing scale.

\`\`\`
<Box padding />
<Box margin />
<Box paddingTop={3} paddingBottom={3} />

<!-- DANGER: Avoid this as much as possible -->
<Box marginTop='-2px' />
\`\`\`

prop | type | description
-----|------| -------
\`padding\` | number/boolean/string | uses 4 on spacing scale by default
\`paddingTop\` | number/boolean/string | uses 4 on spacing scale by default
\`paddingRight\` | number/boolean/string | uses 4 on spacing scale by default
\`paddingBottom\` | number/boolean/string | uses 4 on spacing scale by default
\`paddingLeft\` | number/boolean/string | uses 4 on spacing scale by default
\`margin\` | number/boolean/string | uses 4 on spacing scale by default
\`marginTop\` | number/boolean/string | uses 4 on spacing scale by default
\`marginRight\` | number/boolean/string | uses 4 on spacing scale by default
\`marginBottom\` | number/boolean/string | uses 4 on spacing scale by default
\`marginLeft\` | number/boolean/string | uses 4 on spacing scale by default

### Spacing Scale

**step 4 is default**

scale step number | value
------------------|-------
0 | 0
1 | 4px
2 | 8px
3 | 12px
4 | 16px
5 | 24px
6 | 32px
7 | 40px
8 | 48px
9 | 64px
10 | 80px

# Flex API

Available on \`<Box />\` or \`withFlex(Comp)\`. Uses glamor.

Need a flexbox refresher? [Complete guide to flexbox](https://css-tricks.com/snippets/css/a-guide-to-flexbox/)

\`\`\`
<Box display='flex'>
  <Pane dark padding width={3}>Left</Pane>
  <Pane tint={2} padding flexAuto>Main</Pane>
  <Pane dark padding width={3}>Right</Pane>
</Box>
\`\`\`
`}
          </Content>
          <Box display='flex'>
            <Pane dark padding width={3} flex='0 0 auto'>Left</Pane>
            <Pane tint={2} flexAuto padding>Main</Pane>
            <Pane dark padding width={3} flex='0 0 auto'>Right</Pane>
          </Box>
          <Content markdown>
{`
prop | type | description
-----|------|------------
\`flex\`    | string | flex: x;
\`flexWrap\`    | boolean | flex-wrap: wrap
\`flexAlign\`   | string  | align-items
\`justifyContent\` | center, space-around, space-between, flex-start, flex-end  | justify-content
\`flexColumn\`| boolean | flex-direction: column
\`flexAuto\`| boolean | flex: 1 1 auto
\`flexNone\`| boolean | flex: none
\`flexOrder\`   | number  | order

## Borders API

Available on \`<Box />\` or \`withBorders(Comp)\`. Uses inline styles.

Some components implement a border color already, such as Pane.

prop | type | description
-----|------|------------
\`borderColor\` | string | border-color: x;
\`border\` | boolean | border: 1px solid;
\`borderLeft\` | boolean | border-left: 1px solid;
\`borderRight\` | boolean | border-right: 1px solid;
\`borderTop\` | boolean | border-top: 1px solid;
\`borderBottom\` | boolean | border-bottom: 1px solid;

## Position API

Available on \`<Box />\` or \`withPosition(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`position\` | relative, absolute, fixed, static | position: x;
\`top\` | string | top: x;
\`right\` | string | right: x;
\`bottom\` | string | bottom: x;
\`left\` | string | left: x;

## Rounded API (border radius)

Available on \`<Box />\` or \`withRounded(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`circle\` | bool | border-radius: 9999px
\`rounded\` | bool/1..2/string | adds border radius
\`roundedTop\` | bool/1..2/string | adds border radius
\`roundedTopLeft\` | bool/1..2/string | adds border radius
\`roundedTopRight\` | bool/1..2/string | adds border radius
\`roundedBottom\` | bool/1..2/string | adds border radius
\`roundedBottomLeft\` | bool/1..2/string | adds border radius
\`roundedBottomRight\` | bool/1..2/string | adds border radius
\`roundedLeft\` | bool/1..2/string | adds border radius
\`roundedRight\` | bool/1..2/string | adds border radius

The borderRadius scale contains 1: '5px' and 2: '8px'

`}
          </Content>
          <Pane marginY padding dark circle>circle</Pane>
          <Pane marginY padding dark rounded>rounded</Pane>
          <Pane marginY padding dark roundedTop>roundedTop</Pane>
          <Pane marginY padding dark roundedTopLeft>roundedTopLeft</Pane>
          <Pane marginY padding dark roundedTopRight>roundedTopRight</Pane>
          <Pane marginY padding dark roundedBottom>roundedBottom</Pane>
          <Pane marginY padding dark roundedBottomLeft>roundedBottomLeft</Pane>
          <Pane marginY padding dark roundedBottomRight>roundedBottomRight</Pane>
          <Pane marginY padding dark roundedLeft>roundedLeft</Pane>
          <Pane marginY padding dark roundedRight>roundedRight</Pane>
          <Content markdown>
{`

## Overflow API

Available on \`<Box />\` or \`withOverflow(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`overflow\` | hidden, visible, scroll, auto, inherit, initial | overflow: x;


## Shadow API

Available on \`<Box />\` or \`withShadow(Comp)\`. Uses glamor.

prop | type | description
-----|------|------------
\`shadow\` | boolean/1..2 | 1 | box-shadow: x;

`}
          </Content>
          <Pane tint={2} clearfix>
            <Pane white padding margin rounded shadow>Shadow (1)</Pane>
            <Pane white padding margin rounded shadow={2}>Shadow 2</Pane>
          </Pane>
          <Content markdown>
{`

## Text Align API

Available on \`<Box />\` or \`withTextAlign(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`textAlign\` | left, center, right | text-align: x;

## Truncate API

Available on \`<Box />\` or \`withTruncate(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`truncate\` | boolean | sets overflow ellipsis and props to make it work

## Background API

Available on \`<Box />\` or \`withBackground(Comp)\`. Uses glamor.
Pane implements shorthands for this.

prop | type | description
-----|------|-------------
\`background\` | ${Object.keys(theme.backgrounds).join(', ')} |  sets background-color, border-color and color
\`interactive\` | bool | adds styling on hover and active

`}
          </Content>
          <Box background='dark' clearfix>
            <Box background='white' padding margin>background='white'</Box>
            <Box background='tint' padding margin>background='tint'</Box>
            <Box background='tint1' padding margin>background='tint' === background='tint1'</Box>
            <Box background='tint2' padding margin>background='tint2'</Box>
          </Box>
          <Content markdown>
{`

## Background color API

Available on \`<Box />\` or \`withBackgroundColor(Comp)\`. Uses inline styles.
This is only used as an escape hatch in most cases.
\`<Pane white|tint|dark />\` should be used in general.

prop | type | default | description
-----|------|---------|-------------
\`backgroundColor\` | string | | background-color: x;

## Transform API

Available on \`<Box />\` or \`withTransform(Comp)\`. Uses glamor.

prop | type | description
-----|------|------------
\`transform\` | string | transform: x;

## Clearfix API

Available on \`<Box />\` or \`withClearfix(Comp)\`. Uses glamor.

prop | type | description
-----|------|------------
\`clearfix\` | boolean | | applies a clearfix

`}
          </Content>
        </Pane>
      </App>
    ))
}
